@@ -127,7 +127,7 @@ class Reactor(IReactor):
             self.__loadFluentCommands()
             self.__load_fluent_commands = True
 
-    def __loadFluentCommands(self) -> None:
+    def __loadFluentCommands(self) -> None: # NOSONAR
         """
         Loads and registers commands defined using the fluent interface.
 
@@ -281,7 +281,6 @@ class Reactor(IReactor):
 
         # Import the core command class for version
         from orionis.console.commands.__publisher__ import PublisherCommand
-        from orionis.console.commands.__workflow__ import WorkFlowGithubCommand
         from orionis.console.commands.cache_clear import CacheClearCommand
         from orionis.console.commands.help import HelpCommand
         from orionis.console.commands.log_clear import LogClearCommand
@@ -294,7 +293,6 @@ class Reactor(IReactor):
         # List of core command classes to load (extend this list as more core commands are added)
         core_commands = [
             PublisherCommand,
-            WorkFlowGithubCommand,
             CacheClearCommand,
             HelpCommand,
             LogClearCommand,
@@ -330,7 +328,7 @@ class Reactor(IReactor):
                 args=args
             )
 
-    def __loadCustomCommands(self) -> None:
+    def __loadCustomCommands(self) -> None: # NOSONAR
         """
         Loads command classes from Python files in the specified commands directory.
 
@@ -660,7 +658,7 @@ class Reactor(IReactor):
                 parsed_args = command.args.parse_args(args)
 
             # Raise a CLIOrionisRuntimeError with the help message included in the exception
-            except SystemExit:
+            except Exception:
                 raise CLIOrionisRuntimeError(
                     f"Failed to parse arguments for command '{command.signature}'.\n"
                     f"{command.args.format_help()}\n"
