@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import Optional, Union
 from orionis.console.entities.scheduler_event_data import SchedulerEventData
 
 @dataclass(kw_only=True)
@@ -24,4 +25,4 @@ class SchedulerShutdown(SchedulerEventData):
     """
 
     # The time when the scheduler was shut down; can be a string or datetime object
-    time: str | datetime = None
+    time: Optional[Union[str, datetime]] = None
\ No newline at end of file
