@@ -1,15 +1,12 @@
 from typing import Any
 from orionis.console.kernel import KernelCLI
-from orionis.console.output.contracts.console import IConsole
 from orionis.console.tasks.schedule import Schedule
 from orionis.failure.contracts.catch import ICatch
 from orionis.failure.contracts.handler import IBaseExceptionHandler
 from orionis.foundation.contracts.application import IApplication
-from orionis.services.log.contracts.log_service import ILogger
 
 class Catch(ICatch):
 
-
     def __init__(self, app: IApplication) -> None:
         """
         Initializes the Catch handler with application services for console output and logging.
@@ -38,11 +35,8 @@ class Catch(ICatch):
         error reporting and output.
         """
 
-        # Retrieve the console output service from the application container
-        self.__console: IConsole = app.make('x-orionis.console.output.console')
-
-        # Retrieve the logger service from the application container
-        self.__logger: ILogger = app.make('x-orionis.services.log.log_service')
+        # Store the application instance
+        self.__app: IApplication = app
 
         # Retrieve the console output service from the application container
         self.__exception_handler: IBaseExceptionHandler = app.getExceptionHandler()
@@ -74,21 +68,15 @@ class Catch(ICatch):
         If a valid kernel is provided, the exception details are rendered to the CLI.
         """
 
-        # Check if the exception should be ignored by the handler
-        if self.__exception_handler.shouldIgnoreException(e):
+        # If there is no exception handler, return early
+        if self.__app.call(self.__exception_handler, 'shouldIgnoreException', exception=e):
             return
 
-        # Report the exception using the application's exception handler and logger
-        self.__exception_handler.report(
-            exception=e,
-            log=self.__logger
-        )
+        # Report the exception using the exception handler and logger
+        self.__app.call(self.__exception_handler, 'report', exception=e)
 
-        # If a kernel is provided, render the exception details to the CLI
+        # Check if the kernel is of type `KernelCLI` or `Any`
         if isinstance(kernel, KernelCLI) or isinstance(kernel, Schedule):
-            return self.__exception_handler.renderCLI(
-                request=request,
-                exception=e,
-                log=self.__logger,
-                console=self.__console
-            )
\ No newline at end of file
+
+            # Render the exception details to the CLI using the exception handler
+            self.__app.call(self.__exception_handler, 'renderCLI', exception=e, request=request)
\ No newline at end of file
