@@ -147,7 +147,7 @@ class MySQL(BaseEntity):
         }
     )
 
-    def __post_init__(self):
+    def __post_init__(self): # NOSONAR
         super().__post_init__()
         """
         Post-initialization validation for MySQL database entity configuration.
