@@ -28,5 +28,8 @@ class PrefixedTimedRotatingFileHandler(TimedRotatingFileHandler):
         # Import Application to access configuration settings
         from orionis.support.facades.application import Application
 
+        # Get the default logging channel from configuration, defaulting to 'stack' if not set
+        default_channel = Application.config('logging.default') or 'stack'
+
         # Generate the new filename using FileNameLogger, which adds a timestamp prefix.
-        return FileNameLogger(default_name).generate(Application.config('logging.default', 'stack'))
\ No newline at end of file
+        return FileNameLogger(default_name).generate(default_channel)
\ No newline at end of file
