@@ -14,9 +14,9 @@ class Dumper(Facade):
         Returns
         -------
         str
-            The string "x-orionis.console.contracts.debug.IDebug", which is the binding key
+            The string "x-orionis.console.contracts.dumper.IDumper", which is the binding key
             used to identify and resolve the dumper service from the service container.
         """
 
         # Return the unique binding key for the dumper service in the container
-        return "x-orionis.console.contracts.debug.IDebug"
+        return "x-orionis.console.contracts.dumper.IDumper"
