@@ -140,4 +140,12 @@ class TestResult:
         metadata={
             "description": "Docstring of the test, if applicable."
         }
+    )
+
+    # The exception instance if an error occurred, otherwise None
+    exception: Optional[BaseException] = field(
+        default=None,
+        metadata={
+            "description": "The exception instance if an error occurred, otherwise None."
+        }
     )
\ No newline at end of file
