@@ -4,12 +4,12 @@ class __ValidModuleName:
 
     def __call__(self, module_name) -> str:
         """
-        Validator that ensures the `module_name` parameter is a non-empty string.
+        Validates that the input is a non-empty string.
 
         Parameters
         ----------
         module_name : Any
-            The value to be validated as a non-empty string.
+            The value to validate as a non-empty string.
 
         Returns
         -------
@@ -28,4 +28,4 @@ class __ValidModuleName:
         return module_name
 
 # Exported singleton instance
-ValidModuleName = __ValidModuleName()
+ValidModuleName = __ValidModuleName()
\ No newline at end of file
